@@ -1,5 +1,6 @@
 
 from .any import *
+from .array import *
 from .core import *
 from .dict import *
 from .list import *
@@ -9,6 +10,7 @@ from .number import *
 __all__ = [
     'AnyLike',
     'Anything',
+    'ArrayLike',
     'DictLike',
     'infer_type',
     'ListLike',
